@@ -25,9 +25,12 @@
 #include <gtk/gtk.h>
 #include <gst/gst.h>
 #include <gconf/gconf-client.h>
-#include <hildon/hildon.h>
+
 #include <libosso.h>
 
+#include <hildon/hildon.h>
+#include <hildon-extras/he-about-dialog.h>
+
 #ifdef WITH_SHARING
 
 #ifdef WITH_SHARING_H
@@ -42,7 +45,16 @@ void sharing_dialog_with_file(osso_context_t *osso, GtkWindow *parent, const gch
 #include <dicto/dicto-ui.h>
 #include "config.h"
 
-#include "he-about-dialog.h"
+/* #define PHONE_SRC "liveadder name=phonemixer ! pulsesrc device=sink.hw0.monitor ! phonemixer. pulsesrc device=source.hw0 ! phonemixer." */
+#define PHONE_SRC "adder name=phonemixer pulsesrc device=sink.hw0.monitor ! queue ! phonemixer. pulsesrc device=source.hw0 ! queue ! phonemixer. phonemixer. ! queue"
+#define SYSTEM_SRC "pulsesrc device=sink.hw0.monitor ! audioconvert ! queue "
+
+typedef enum {
+	SRC_MIC=0,
+	SRC_PHONE=1,
+	SRC_SYSTEM=2,
+	SRC_END=999
+} myDSrcId;
 
 typedef struct _MyDicto MyDicto;
 struct _MyDicto {
@@ -62,16 +74,24 @@ struct _MyDicto {
 
 MyDicto mapp;
 
+typedef struct _MyDictoSrc MyDictoSrc;
+struct _MyDictoSrc {
+	myDSrcId id;
+	gchar *name;
+	gchar *src;
+};
+
+static MyDictoSrc sources[]={
+	{ SRC_MIC,	"Microphone", AUDIO_SRC },
+	{ SRC_PHONE,	"Phone", PHONE_SRC },
+	{ SRC_SYSTEM,	"System", SYSTEM_SRC },
+	{ SRC_END,	NULL, NULL }
+};
+
 #define MYDICTO_GCONF_PATH "/apps/mydicto"
 #define MYDICTO_GCONF_AUDIO_FORMAT_MIC MYDICTO_GCONF_PATH  "/audio-format"
 #define MYDICTO_GCONF_AUDIO_FORMAT_PHONE MYDICTO_GCONF_PATH  "/audio-format-phone"
 
-/* #define PHONE_SRC "liveadder name=phonemixer ! pulsesrc device=sink.hw0.monitor ! phonemixer. pulsesrc device=source.hw0 ! phonemixer." */
-#define PHONE_SRC "adder name=phonemixer pulsesrc device=sink.hw0.monitor ! queue ! phonemixer. pulsesrc device=source.hw0 ! queue ! phonemixer. phonemixer. ! queue"
-
-#define SRC_MIC 0
-#define SRC_PHONE 1
-
 static void
 mydicto_gconf_store(MyDicto *md)
 {
@@ -204,6 +224,9 @@ switch (srcid) {
 	case SRC_PHONE:
 		mapp.d=mapp.dp;
 	break;
+	default:
+		g_return_if_reached();
+	break;
 }
 g_object_set(mapp.dw, "dicto", mapp.d, NULL);
 }
@@ -228,7 +251,7 @@ gchar *desc, *msg;
 if (!get_selected_id_from_selector(selector, &id, &desc))
 	return;
 if (!dicto_set_format(mapp.d, (DictoFormats)id)) {
-	hildon_banner_show_information(GTK_WIDGET(mapp.window), "", _("Failed to set new format"));
+	hildon_banner_show_information(GTK_WIDGET(mapp.window), "", _("Failed to set recording format"));
 	return;
 }
 msg=g_strdup_printf("Using format:\n%s", desc);
@@ -282,7 +305,7 @@ g_signal_connect_after(mapp.sharing_button, "clicked", G_CALLBACK(mydicto_menu_b
 hildon_app_menu_append(menu, GTK_BUTTON(mapp.sharing_button));
 
 mapp.source_button=hildon_picker_button_new(HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-hildon_button_set_title(HILDON_BUTTON(mapp.source_button), _("Source"));
+hildon_button_set_title(HILDON_BUTTON(mapp.source_button), _("Recording source"));
 src_selector=hildon_touch_selector_new_text();
 hildon_touch_selector_append_text(src_selector, _("Microphone"));
 hildon_touch_selector_append_text(src_selector, _("Phone"));
@@ -292,7 +315,7 @@ hildon_picker_button_set_selector(HILDON_PICKER_BUTTON(mapp.source_button), HILD
 hildon_app_menu_append(menu, GTK_BUTTON(mapp.source_button));
 
 mapp.format_button=hildon_picker_button_new(HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-hildon_button_set_title(HILDON_BUTTON(mapp.format_button), _("Format"));
+hildon_button_set_title(HILDON_BUTTON(mapp.format_button), _("Recording format"));
 f_selector=hildon_touch_selector_new();
 column=hildon_touch_selector_append_column(f_selector, GTK_TREE_MODEL(mapp.formats), gtk_cell_renderer_text_new(), "text", 1, NULL);
 hildon_touch_selector_column_set_text_column(column, 1);
@@ -301,7 +324,7 @@ hildon_touch_selector_set_column_selection_mode(f_selector, HILDON_TOUCH_SELECTO
 hildon_app_menu_append(menu, GTK_BUTTON(mapp.format_button));
 
 mapp.about_button=hildon_gtk_button_new(HILDON_SIZE_AUTO);
-gtk_button_set_label(mapp.about_button, _("About"));
+gtk_button_set_label(GTK_BUTTON(mapp.about_button), _("About"));
 hildon_app_menu_append(menu, GTK_BUTTON(mapp.about_button));
 
 g_signal_connect(G_OBJECT(mapp.format_button), "value-changed", G_CALLBACK(mydicto_format_cb), f_selector);
@@ -330,22 +353,6 @@ return menu;
 }
 #endif
 
-static void
-dicto_format_select_cb(GtkComboBox *widget, gpointer data)
-{
-GtkTreeIter iter;
-GtkTreeModel *model;
-gint value=-1;
-
-model=gtk_combo_box_get_model(widget);
-if (!gtk_combo_box_get_active_iter(widget, &iter))
-	return;
-
-gtk_tree_model_get(model, &iter, 0, &value,  -1);
-if (!dicto_set_format(mapp.d, value))
-	hildon_banner_show_information(GTK_WIDGET(mapp.window), "", _("Failed to set format"));
-}
-
 static void
 mydicto_connect_dicto(Dicto *d, MyDicto *md)
 {
